@@ -1,10 +1,13 @@
 #!/usr/bin/env python2
 # coding=utf-8
 
+"""
+Provides gitver's version by dynamically loading the optional _version module.
+"""
 
-gitver_version = ''
-gitver_buildid = ''
-gitver_pypi = ''
+gitver_version = None
+gitver_buildid = None
+gitver_pypi = None
 
 try:
     import _version as v
